FileUtils class abstract

Interface for file utility functions

Constructors

FileUtils()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pickWebFilesForUpload({bool allowMultiple = false, List<String> acceptedFileTypes = const []}) Future<List<XFile>?>
Picks files using the browser's file selector and converts them to XFiles.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited