TusFileStore class

TusFileStore is used for storing upload progress locally on the device. It is used by TusClient to resume uploads at correct %.

Implemented types

Constructors

TusFileStore(Directory directory, {bool debug = false})
It must receive the directory to store the upload.

Properties

directory Directory
The directory where the upload is stored.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

get(String fingerprint) Future<Uri?>
Retrieve an upload's Uri for a fingerprint. If no matching entry is found this method will return null.
override
isDebugEnabled() bool
Get current debug status
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove(String fingerprint) Future<void>
Remove an entry from the store using an upload's fingerprint.
override
set(String fingerprint, Uri url) Future<void>
Store a new fingerprint and its upload url. The fingerprint is generated by TusClient and is used to identify the upload.
override
setDebug(bool value) → void
Enable or disable debug logging
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited