TusMemoryStore class

This class is used to lookup a fingerprint with the corresponding file entries in a Map.

This functionality is used to allow resuming uploads.

This store will not keep the values after your application crashes or restarts.

Implemented types

Constructors

TusMemoryStore({bool debug = false})
Create a new memory store with optional debug logging

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
store Map<String, Uri>
getter/setter pair

Methods

get(String fingerprint) Future<Uri?>
Retrieve an upload's Uri for a fingerprint. If no matching entry is found this method will return null.
override
isDebugEnabled() bool
Get current debug status
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove(String fingerprint) Future<void>
Remove an entry from the store using an upload's fingerprint.
override
set(String fingerprint, Uri url) Future<void>
Store a new fingerprint and its upload url.
override
setDebug(bool value) → void
Enable or disable debug logging
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited