TusStore class abstract

Base interface for TusStore implementations

Implementers

Constructors

TusStore()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

get(String fingerprint) Future<Uri?>
Retrieve an upload's Uri for a fingerprint. If no matching entry is found this method will return null.
isDebugEnabled() bool
Get current debug status
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove(String fingerprint) Future<void>
Remove an entry from the store using an upload's fingerprint.
set(String fingerprint, Uri url) Future<void>
Store a new fingerprint and its upload url.
setDebug(bool value) → void
Enable or disable debug logging
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited