UploadStatus enum

Status of an upload managed by TusUploadManager

Inheritance
Available extensions

Values

ready → const UploadStatus

Upload is ready but not started

uploading → const UploadStatus

Upload is in progress

paused → const UploadStatus

Upload is paused

completed → const UploadStatus

Upload is completed

failed → const UploadStatus

Upload failed with an error

cancelled → const UploadStatus

Upload was canceled

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<UploadStatus>
A constant List of the values in this enum, in order of their declaration.