another_tus_client library
Classes
- FileUtils
- Interface for file utility functions
- ManagedUpload
- Information about a managed upload
- NativeWebXFile
- XFile implementation that supports efficient streaming from web.File objects.
- TusClient
- This class is used for creating or resuming uploads.
- TusFileStore
- TusFileStore is used for storing upload progress locally on the device. It is used by TusClient to resume uploads at correct %.
- TusIndexedDBStore
- TusIndexedDBStore uses browser IndexedDB for storing upload URLs. Useful for larger or more complex data than localStorage can handle.
- TusMemoryStore
-
This class is used to lookup a
fingerprintwith the correspondingfileentries in a Map. - TusStore
- Base interface for TusStore implementations
- TusUploadManager
- Manager for handling multiple TUS uploads
- UploadEvent
Enums
- RetryScale
- UploadEventType
- UploadStatus
- Status of an upload managed by TusUploadManager
Functions
-
createXFileFromWebFile(
File file, {String? mimeType}) → XFile - Creates an XFile from a native web.File object.
-
pickWebFilesForUpload(
{bool allowMultiple = false, List< String> acceptedFileTypes = const []}) → Future<List< XFile> ?> - Picks files using the browser's file selector and converts them to XFiles.
-
selectWebFiles(
{bool allowMultiple = false, List< String> acceptedFileTypes = const []}) → Future<List< File> > - Selects files using the browser's native file picker without loading file contents.
Typedefs
Exceptions / Errors
- ProtocolException
- This exception is thrown if the server sends a request with an unexpected status code or missing/invalid headers.