ManagedUpload class
Information about a managed upload
Constructors
Properties
- client → TusClient
-
The TusClient instance handling this upload
final
- createdAt → DateTime
-
Created timestamp
final
- error ↔ String?
-
Error message if status is UploadStatus.failed
getter/setter pair
- estimate ↔ Duration
-
Estimated time remaining
getter/setter pair
- fingerprint → String
-
This is a unique hash of the file being uploaded
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
headers
→ Map<
String, String> ? -
Headers for this upload
final
- id → String
-
Unique ID for this upload
final
-
metadata
→ Map<
String, String> ? -
Metadata for this upload
final
- progress ↔ double
-
Progress from 0.0 to 100.0
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status ↔ UploadStatus
-
Current status of the upload
getter/setter pair
- updatedAt ↔ DateTime
-
Last updated timestamp
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
updateProgress(
double newProgress, Duration newEstimate) → void - Update the progress and estimated time
-
updateStatus(
UploadStatus newStatus, {String? errorMessage}) → void - Update the upload status and timestamps
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited