RetryScale enum
Values
- constant → const RetryScale
-
Same time interval between every retry.
- lineal → const RetryScale
-
If interval is n, on every retry the the interval is increased by n. For example if
retryIntervalis set to 2 seconds, and theretriesis set to 4, the interval for every retry is going to be2, 4, 6, 8 - exponential → const RetryScale
-
If interval is n, on every retry the last interval is going to be duplicated. For example if
retryIntervalis set to 2 seconds, and theretriesis set to 4, the interval for every retry is going to be2, 4, 8, 16
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getInterval(
int retry, int retryInterval) → Duration -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
RetryScale> - A constant List of the values in this enum, in order of their declaration.