TusIndexedDBStore class
TusIndexedDBStore uses browser IndexedDB for storing upload URLs. Useful for larger or more complex data than localStorage can handle.
- Implemented types
Constructors
- TusIndexedDBStore({String dbName = 'tus_uploads', String storeName = 'files', int dbVersion = 1, bool debug = false})
- Create a new IndexedDB store with optional debug logging
Properties
Methods
-
get(
String fingerprint) → Future< Uri?> -
Retrieve an upload's Uri for a
fingerprint. If no matching entry is found this method will returnnull.override -
isDebugEnabled(
) → bool -
Get current debug status
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
remove(
String fingerprint) → Future< void> -
Remove an entry from the store using an upload's
fingerprint.override -
set(
String fingerprint, Uri url) → Future< void> -
Store a new
fingerprintand its uploadurl.override -
setDebug(
bool value) → void -
Enable or disable debug logging
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited